LinearLayout

Struct LinearLayout 

pub struct LinearLayout { /* private fields */ }
A layout that uses a linear algorithm, with optional wrapping

Implementations

Source

impl LinearLayout

pub const fn new(axis: Axis) -> Self

Create a new LinearLayout builder using this Axis

pub const fn axis(self, axis: Axis) -> Self

Change the Axis of this builder

pub const fn anchor(self, anchor: Anchor2) -> Self

Set the anchor for this builder.

An anchor is where the layout starts from

e.g.:

pub const fn horizontal_anchor(self, anchor: Anchor) -> Self

Set the horizontal anchor for this builder

A horizontal anchor where where on the x axis the layout begins

pub const fn vertical_anchor(self, anchor: Anchor) -> Self

Set the vertical anchor for this builder

A vertical anchor where where on the y axis the layout begins

pub const fn horizontal() -> Self

Create a default horizontal layout builder

pub const fn vertical() -> Self

Create a default vertical layout builder

pub const fn wrap(self, wrap: bool) -> Self

Should this layout wrap?

pub const fn spacing(self, spacing: Vec2) -> Self

The spacing for the layout.

Spacing is the gap between 2 elements.

  • spacing.x is the horizontal spacing
  • spacing.y is the vertical spacing
pub fn layout(self, rect: Rect) -> LinearAllocator

Construct the LinearAllocator from this type

This takes in the target Rect that the allocator will fit everything into.