Module view

Module view 

Types for implementing and interacting with Ui elements

Modules

debug
Debug helpers for a view
test
A simplistic testing interface for your applications.

Structs

CroppedSurface
A Surface cropped to a specific Rect
Debug
A debug overlay
Elements
Useful elements for drawing a TUI
EventCtx
A context passed to event handlers
InputState
The input state tree.
Interest
Interests for events that a view want to recieve
IntrinsicSize
Context for calculating the intrinstic size of a view
Layout
Layout context
LayoutNode
A node in the layout tree for a view
LayoutNodes
The tree for the layouts of all of the views
Palette
A color palette used by the common crate::views
Render
The render context
Response
A response from a view
State
State is the entire state for a Ui
Ui
ViewId
An opaque ID for a View in the current UI tree
ViewNode
A node for a view into the main UI tree
ViewNodes
The persistent tree of all of the views.

Enums

DebugMode
Controls the behavior of the Debug overlay
Handled
A response to an event
Layer
A layer a view should be on, relative to its parent
StyleKind
Views have the ability to style themselves.
ViewEvent
Events a view can receive

Traits

Adhoc
Adhoc views are views built out of other views
Builder
Builders are required to build and update views
View
View is the main trait for describing a view.
ViewExt
An extension trait that is implemented for all Builders

Functions

debug
Prints a debug message to the debug overlay.
measure_textDeprecated