Interest

Struct Interest 

pub struct Interest(/* private fields */);
Interests for events that a view want to recieve

Implementations

Source

impl Interest

pub const NONE: Self

No events should be sent to a view

pub const ALL: Self

All events should be sent to a view

pub const MOUSE_INSIDE: Self

A view wants to get mouse events inside of it

pub const MOUSE_OUTSIDE: Self

A view wants to get mouse events outside of it

pub const MOUSE_MOVE: Self

A view wants to get mouse move events

pub const FOCUS: Self

A view wants to get ViewEvent::FocusGained and ViewEvent::FocusLost events

pub const FOCUS_INPUT: Self

A view wants to key inputs

pub const SELECTION_CHANGE: Self

pub const MOUSE: Self

A view wants all mouse events

Source

impl Interest

pub const fn is_none(&self) -> bool

pub const fn is_mouse_inside(&self) -> bool

pub const fn is_mouse_outside(&self) -> bool

pub const fn is_mouse_move(&self) -> bool

pub const fn is_mouse_any(&self) -> bool

pub const fn is_focus(&self) -> bool

pub const fn is_focus_input(&self) -> bool

pub const fn is_selection_change(&self) -> bool