Palette

Struct Palette 

pub struct Palette {
    pub background: Rgba,
    pub foreground: Rgba,
    pub surface: Rgba,
    pub outline: Rgba,
    pub contrast: Rgba,
    pub primary: Rgba,
    pub secondary: Rgba,
    pub accent: Rgba,
    pub danger: Rgba,
    pub success: Rgba,
    pub warning: Rgba,
    pub info: Rgba,
}
A color palette used by the common crate::views

Fields

background: Rgba

The background color

foreground: Rgba

The foreground color

surface: Rgba

A color close to the background, but more visible

outline: Rgba

A color used to outline things. This is generally like surface, but even more visible

contrast: Rgba

A color used to contrast something against the background

primary: Rgba

A color used for a primary action – e.g. the default interaction color

secondary: Rgba

A color used for a secondary action – e.g an interaction color that is different from the primary color

accent: Rgba

A accent color used to differentiate something from a primary and secondary color

danger: Rgba

A color representing that something is dangerous

success: Rgba

A color representing that something is successful

warning: Rgba

A color representing that something is potentially dangerous

info: Rgba

A coloe representing that something should be noted

Implementations

Source

impl Palette

pub fn is_dark(&self) -> bool

Is this background’s luminosity considered ‘dark’?

pub fn is_light(&self) -> bool

Is this background’s luminosity considered ‘light’?

pub const fn dark() -> Self

A default “dark” palette

A visualization of this palette
ColorVisualization
foreground#FFFFFF
surface#232323
outline#4D4D4D
contrast#A9E9E9
primary#55B1F0
secondary#8C8BED
accent#F4A151
danger#F05D61
success#9AF07A
warning#F9F35F
info#6A7DDA

(All text is on the Palette::background color)

pub const fn light() -> Self

A default “light” palette

A visualization of this palette
ColorVisualization
foreground#000000
surface#C3C5C8
outline#9D9099
contrast#663696
primary#8175DF
secondary#28758D
accent#776BC2
danger#C7343B
success#33D17A
warning#F9F35F
info#0077C2

(All text is on the Palette::background color)