pub struct KeyArea { /* private fields */ }Trait Implementations
Sourceimpl View for KeyArea
impl View for KeyArea
Sourcetype Response = KeyAreaResponse
type Response = KeyAreaResponse
Response from this view that is given to the user Read more
Sourcefn create(args: Self::Args<'_>) -> Self
fn create(args: Self::Args<'_>) -> Self
Create your view with the args provided from the user Read more
Sourcefn update(&mut self, _args: Self::Args<'_>, _ui: &Ui<'_>) -> Self::Response
fn update(&mut self, _args: Self::Args<'_>, _ui: &Ui<'_>) -> Self::Response
Update your view with the args provided from the user Read more
Sourcefn flex(&self) -> Flex
fn flex(&self) -> Flex
If your view can be flexible, this returns how flexible it is. Read more
Sourcefn primary_axis(&self) -> Axis
fn primary_axis(&self) -> Axis
The primary axis of your view. Read more
Sourcefn size(&self, intrinsic: IntrinsicSize<'_>, axis: Axis, extent: f32) -> f32
fn size(&self, intrinsic: IntrinsicSize<'_>, axis: Axis, extent: f32) -> f32
This is a hint can be used for determining how much space a view will
take up on a specific axis with a specific extent (width/height). Read more
Sourcefn default_event(&mut self, event: ViewEvent, ctx: EventCtx<'_>) -> Handled
fn default_event(&mut self, event: ViewEvent, ctx: EventCtx<'_>) -> Handled
The default event handling behavior to delegate to your children. Read more
Sourcefn default_layout(&mut self, layout: Layout<'_>, space: Space) -> Size
fn default_layout(&mut self, layout: Layout<'_>, space: Space) -> Size
The default layout handling behavior to delegate to your children. Read more
Sourcefn default_draw(&mut self, render: Render<'_, '_>)
fn default_draw(&mut self, render: Render<'_, '_>)
The default draw handling behavior to delegate to your children. Read more