pub struct LinearLayout { /* private fields */ }Expand description
A layout that uses a linear algorithm, with optional wrapping
Implementations
Sourceimpl LinearLayout
impl LinearLayout
Sourcepub const fn new(axis: Axis) -> Self
pub const fn new(axis: Axis) -> Self
Create a new LinearLayout builder using this Axis
Sourcepub const fn anchor(self, anchor: Anchor2) -> Self
pub const fn anchor(self, anchor: Anchor2) -> Self
Set the anchor for this builder.
An anchor is where the layout starts from
e.g.:
Sourcepub const fn horizontal_anchor(self, anchor: Anchor) -> Self
pub const fn horizontal_anchor(self, anchor: Anchor) -> Self
Set the horizontal anchor for this builder
A horizontal anchor where where on the x axis the layout begins
Sourcepub const fn vertical_anchor(self, anchor: Anchor) -> Self
pub const fn vertical_anchor(self, anchor: Anchor) -> Self
Set the vertical anchor for this builder
A vertical anchor where where on the y axis the layout begins
Sourcepub const fn horizontal() -> Self
pub const fn horizontal() -> Self
Create a default horizontal layout builder
Sourcepub const fn spacing(self, spacing: Vec2) -> Self
pub const fn spacing(self, spacing: Vec2) -> Self
The spacing for the layout.
Spacing is the gap between 2 elements.
spacing.xis the horizontal spacingspacing.yis the vertical spacing
Sourcepub fn layout(self, rect: Rect) -> LinearAllocator
pub fn layout(self, rect: Rect) -> LinearAllocator
Construct the LinearAllocator from this type
This takes in the target Rect that the allocator will fit everything into.