Types for implementing and interacting with Ui elements
Modules
Structs
- Cropped
Surface - A
Surfacecropped to a specificRect - Debug
- A debug overlay
- Elements
- Useful elements for drawing a TUI
- Event
Ctx - A context passed to event handlers
- Input
State - The input state tree.
- Interest
- Interests for events that a view want to recieve
- Intrinsic
Size - Context for calculating the intrinstic size of a view
- Layout
- Layout context
- Layout
Node - A node in the layout tree for a view
- Layout
Nodes - The tree for the layouts of all of the views
- Palette
- A color palette used by the common
crate::views - Render
- The render context
- Response
- A response from a view
- State
- State is the entire state for a
Ui - Ui
- ViewId
- An opaque ID for a
Viewin the current UI tree - View
Node - A node for a view into the main UI tree
- View
Nodes - The persistent tree of all of the views.
Enums
- Debug
Mode - Controls the behavior of the
Debugoverlay - Handled
- A response to an event
- Layer
- A layer a view should be on, relative to its parent
- Style
Kind - Views have the ability to style themselves.
- View
Event - Events a view can receive
Traits
- Adhoc
- Adhoc views are views built out of other views
- Builder
- Builders are required to build and update views
- View
- View is the main trait for describing a view.
- ViewExt
- An extension trait that is implemented for all
Builders
Functions
- debug
- Prints a debug message to the debug overlay.
- measure_
text Deprecated