pub struct Interest(/* private fields */);Expand description
Interests for events that a view want to recieve
Implementations
Sourceimpl Interest
impl Interest
Sourcepub const MOUSE_INSIDE: Self
pub const MOUSE_INSIDE: Self
A view wants to get mouse events inside of it
Sourcepub const MOUSE_OUTSIDE: Self
pub const MOUSE_OUTSIDE: Self
A view wants to get mouse events outside of it
Sourcepub const MOUSE_MOVE: Self
pub const MOUSE_MOVE: Self
A view wants to get mouse move events
Sourcepub const FOCUS: Self
pub const FOCUS: Self
A view wants to get ViewEvent::FocusGained and ViewEvent::FocusLost events
Sourcepub const FOCUS_INPUT: Self
pub const FOCUS_INPUT: Self
A view wants to key inputs
Sourcepub const SELECTION_CHANGE: Self
pub const SELECTION_CHANGE: Self
A view wants to get ViewEvent::SelectionAdded and ViewEvent::SelectionRemoved events
Sourceimpl Interest
impl Interest
pub const fn is_none(&self) -> bool
pub const fn is_mouse_inside(&self) -> bool
pub const fn is_mouse_outside(&self) -> bool
pub const fn is_mouse_move(&self) -> bool
pub const fn is_mouse_any(&self) -> bool
pub const fn is_focus(&self) -> bool
pub const fn is_focus_input(&self) -> bool
pub const fn is_selection_change(&self) -> bool