pub struct Palette {
pub background: Rgba,
pub foreground: Rgba,
pub surface: Rgba,
pub outline: Rgba,
pub contrast: Rgba,
pub primary: Rgba,
pub secondary: Rgba,
pub accent: Rgba,
pub danger: Rgba,
pub success: Rgba,
pub warning: Rgba,
pub info: Rgba,
}Expand description
A color palette used by the common crate::views
Fields
background: RgbaThe background color
foreground: RgbaThe foreground color
surface: RgbaA color close to the background, but more visible
outline: RgbaA color used to outline things. This is generally like surface, but even more visible
contrast: RgbaA color used to contrast something against the background
primary: RgbaA color used for a primary action – e.g. the default interaction color
secondary: RgbaA color used for a secondary action – e.g an interaction color that is different from the primary color
accent: RgbaA accent color used to differentiate something from a primary and secondary color
danger: RgbaA color representing that something is dangerous
success: RgbaA color representing that something is successful
warning: RgbaA color representing that something is potentially dangerous
info: RgbaA coloe representing that something should be noted
Implementations
Sourceimpl Palette
impl Palette
Sourcepub const fn dark() -> Self
pub const fn dark() -> Self
A default “dark” palette
A visualization of this palette
| Color | Visualization |
|---|---|
| foreground | #FFFFFF |
| surface | #232323 |
| outline | #4D4D4D |
| contrast | #A9E9E9 |
| primary | #55B1F0 |
| secondary | #8C8BED |
| accent | #F4A151 |
| danger | #F05D61 |
| success | #9AF07A |
| warning | #F9F35F |
| info | #6A7DDA |
(All text is on the Palette::background color)
Sourcepub const fn light() -> Self
pub const fn light() -> Self
A default “light” palette
A visualization of this palette
| Color | Visualization |
|---|---|
| foreground | #000000 |
| surface | #C3C5C8 |
| outline | #9D9099 |
| contrast | #663696 |
| primary | #8175DF |
| secondary | #28758D |
| accent | #776BC2 |
| danger | #C7343B |
| success | #33D17A |
| warning | #F9F35F |
| info | #0077C2 |
(All text is on the Palette::background color)